@@ -18,7 +18,7 @@ use Readonly;
 use Data::Walk;
 use Try::Tiny;
 
-our $VERSION = 1.02;
+our $VERSION = 1.03;
 
 our $override;
 my $JSON_OBJ = Cpanel::JSON::XS->new()->utf8->pretty();
@@ -91,8 +91,7 @@ sub _initialize {
         $self->_set_mock_dbh($data);
     }
     else {
-        croak
-"No mocked data is available, you can resolve this by providing the 'dbh'
+        croak "No mocked data is available, you can resolve this by providing the 'dbh'
 		argument to the 'new' method to generate it. Alternatively, you can pass either
 		a file or data argument to the 'new' method";
     }
@@ -114,6 +113,7 @@ sub _set_mock_dbh {
 
     my $dbh_session = DBD::Mock::Session->new( $PROGRAM_NAME => @{$data} );
     $self->_override_dbi_mocked_prepare( $MOCKED_DBI_METHODS{mocked_prepare} );
+
     $dbh->{mock_session} = $dbh_session;
     $self->{dbh}         = $dbh;
 
@@ -125,23 +125,15 @@ sub _override_dbi_methods {
 
     $self->_override_dbi_execute( $MOCKED_DBI_METHODS{execute} );
     $self->_override_dbi_bind_param( $MOCKED_DBI_METHODS{bind_param} );
-    $self->_override_dbi_fetchrow_hashref(
-        $MOCKED_DBI_METHODS{fetchrow_hashref} );
-    $self->_override_dbi_fetchrow_arrayref(
-        $MOCKED_DBI_METHODS{fetchrow_arrayref} );
+    $self->_override_dbi_fetchrow_hashref( $MOCKED_DBI_METHODS{fetchrow_hashref} );
+    $self->_override_dbi_fetchrow_arrayref( $MOCKED_DBI_METHODS{fetchrow_arrayref} );
     $self->_override_dbi_fetchrow_array( $MOCKED_DBI_METHODS{fetchrow_array} );
-    $self->_override_dbi_selectall_arrayref(
-        $MOCKED_DBI_METHODS{selectall_arrayref} );
-    $self->_override_dbi_selectall_hashref(
-        $MOCKED_DBI_METHODS{selectall_hashref} );
-    $self->_override_dbi_selectcol_arrayref(
-        $MOCKED_DBI_METHODS{selectcol_arrayref} );
-    $self->_override_dbi_selectrow_array(
-        $MOCKED_DBI_METHODS{selectrow_array} );
-    $self->_override_dbi_selectrow_arrayref(
-        $MOCKED_DBI_METHODS{selectrow_arrayref} );
-    $self->_override_dbi_selectrow_hashref(
-        $MOCKED_DBI_METHODS{selectrow_hashref} );
+    $self->_override_dbi_selectall_arrayref( $MOCKED_DBI_METHODS{selectall_arrayref} );
+    $self->_override_dbi_selectall_hashref( $MOCKED_DBI_METHODS{selectall_hashref} );
+    $self->_override_dbi_selectcol_arrayref( $MOCKED_DBI_METHODS{selectcol_arrayref} );
+    $self->_override_dbi_selectrow_array( $MOCKED_DBI_METHODS{selectrow_array} );
+    $self->_override_dbi_selectrow_arrayref( $MOCKED_DBI_METHODS{selectrow_arrayref} );
+    $self->_override_dbi_selectrow_hashref( $MOCKED_DBI_METHODS{selectrow_hashref} );
     $self->_override_dbi_fecth( $MOCKED_DBI_METHODS{fetch} );
     $self->_override_dbi_prepare_cached( $MOCKED_DBI_METHODS{prepare_cached} );
     $self->_override_dbi_prepare( $MOCKED_DBI_METHODS{prepare} );
@@ -266,8 +258,7 @@ sub _override_dbi_fetchrow_hashref {
             my $retval = $orig_selectrow_hashref->($sth);
 
             if ( ref $retval && !defined $self->{result}->[-1]->{results} ) {
-                my $query_results =
-                  $self->_set_hashref_response( $sth, $retval );
+                my $query_results = $self->_set_hashref_response( $sth, $retval );
                 push @{ $self->{result}->[-1]->{results} }, $query_results;
                 $self->_write_to_file();
             }
@@ -343,9 +334,8 @@ sub _override_dbi_selectall_arrayref {
         sub {
             my ( $dbh, $sql, $slice, @parmas ) = @_;
 
-            my $retval =
-              $orig_selectall_arrayref->( $dbh, $sql, $slice, @parmas );
-            my $data = [];
+            my $retval = $orig_selectall_arrayref->( $dbh, $sql, $slice, @parmas );
+            my $data   = [];
 
             if ( ref $retval ) {
                 my $col_names = $self->_get_current_record_column_names();
@@ -380,17 +370,14 @@ sub _override_dbi_selectall_hashref {
         sub {
             my ( $dbh, $statement, $key_field, $attr, @bind_values ) = @_;
 
-            my $retval = $orig_selectall_hashref->(
-                $dbh, $statement, $key_field, $attr, @bind_values
-            );
+            my $retval = $orig_selectall_hashref->( $dbh, $statement, $key_field, $attr, @bind_values );
 
             my $col_names = $self->_get_current_record_column_names();
             my $mock_data = [];
 
             walk sub {
                 my $rows = $_;
-                if ( ref $rows && scalar keys %{$rows} == scalar @{$col_names} )
-                {
+                if ( ref $rows && scalar keys %{$rows} == scalar @{$col_names} ) {
                     my %data = %$rows;
                     push @{$mock_data}, [ @data{ @{$col_names} } ];
                     $self->_write_to_file();
@@ -419,9 +406,7 @@ sub _override_dbi_selectcol_arrayref {
             my ( $dbh, $statement, $attr, @bind_values ) = @_;
             my $mocked_data = [];
 
-            my $retval = $orig_selectcol_arrayref->(
-                $dbh, $statement, $attr, @bind_values
-            );
+            my $retval  = $orig_selectcol_arrayref->( $dbh, $statement, $attr, @bind_values );
             my @db_data = @{$retval};
 
             my $length = 1;
@@ -463,9 +448,7 @@ sub _override_dbi_selectrow_array {
             }
 
             my $sql    = $sth->{Statement};
-            my @retval = $original_selectrow_array->(
-                $dbh, $statement, $attr, @bind_values
-            );
+            my @retval = $original_selectrow_array->( $dbh, $statement, $attr, @bind_values );
 
             my $query_data = {
                 statement    => $sql,
@@ -504,9 +487,7 @@ sub _override_dbi_selectrow_arrayref {
             }
 
             my $sql    = $sth->{Statement};
-            my $retval = $original_selectrow_arrayref->(
-                $dbh, $statement, $attr, @bind_values
-            );
+            my $retval = $original_selectrow_arrayref->( $dbh, $statement, $attr, @bind_values );
 
             my $query_data = {
                 statement    => $sql,
@@ -545,9 +526,7 @@ sub _override_dbi_selectrow_hashref {
             }
 
             my $sql    = $sth->{Statement};
-            my $retval = $original_selectrow_hashref->(
-                $dbh, $statement, $attr, @bind_values
-            );
+            my $retval = $original_selectrow_hashref->( $dbh, $statement, $attr, @bind_values );
 
             $self->{result}->[-1]->{results} =
               [ $self->_set_hashref_response( $sth, $retval ) ];
@@ -575,8 +554,7 @@ sub _override_dbi_fecth {
                 if (   $sth->{Statement} =~ /WHERE/i
                     && $sth->{Statement} !~ /ORDER BY/i )
                 {
-                    unshift @{ $self->{result}->[-1]->{results} },
-                      \@shallow_copy;
+                    unshift @{ $self->{result}->[-1]->{results} }, \@shallow_copy;
                 }
                 else {
                     push @{ $self->{result}->[-1]->{results} }, \@shallow_copy;
@@ -676,8 +654,7 @@ sub _override_dbi_commit {
         sub {
             my $dbh = shift;
 
-            push @{ $self->{result} },
-              { statement => 'COMMIT', col_names => undef, results => [ [] ] };
+            push @{ $self->{result} }, { statement => 'COMMIT', col_names => undef, results => [ [] ] };
             $self->_write_to_file();
             return $original_commit->($dbh);
         }
@@ -724,13 +701,20 @@ sub _get_current_record_column_names {
 sub _process_mock_data {
     my ( $self, $data ) = @_;
 
-    foreach my $row ( @{$data} ) {
+    while ( my ( $index, $row ) = each( @{$data} ) ) {
+        if ( $row->{statement} eq "ROLLBACK" ) {
+            $data->[ $index - 1 ]->{err}     = 1062;
+            $data->[ $index - 1 ]->{results} = undef;
+            $data->[ $index - 1 ]->{errstr}  = 'Rollback kicked in';
+        }
+
         if ( $row->{col_names} ) {
             my $cols = delete $row->{col_names};
             unshift @{ $row->{results} }, $cols;
         }
     }
 
+    # say Dumper $data;
     return $self;
 }
 
@@ -744,11 +728,9 @@ sub _set_fixtures_file {
         $self->{fixture_file} = $file;
     }
     else {
-        my ( $volume, $directory, $test_file ) =
-          File::Spec->splitpath($PROGRAM_NAME);
+        my ( $volume, $directory, $test_file ) = File::Spec->splitpath($PROGRAM_NAME);
         make_path( $directory . $FIXTURE_DIR );
-        my $default_fixture_file =
-          $directory . $FIXTURE_DIR . "$test_file.json";
+        my $default_fixture_file = $directory . $FIXTURE_DIR . "$test_file.json";
         $self->{fixture_file} = $default_fixture_file;
     }
 
